import json
import codecs
import numpy as np
from tqdm import tqdm

def write_json(filename,res,isIndent = False, isLine = True):
    
    if not isLine and not isinstance(res,dict) and not isinstance(res,list):
        if isIndent:
            json_str = json.dumps(res,ensure_ascii=False,indent=4)
            with open(filename, 'w',encoding = 'utf-8') as json_file:
                json_file.write(json_str)
        else:
            json_str = json.dumps(res,ensure_ascii=False)
            with open(filename, 'w',encoding = 'utf-8') as json_file:
                json_file.write(json_str)
    else:        
        with codecs.open(filename, 'w', 'utf-8') as f:
            for formatted_instance in res:
                json_str = json.dumps(formatted_instance, ensure_ascii=False)
                f.write(json_str)
                f.write('\n')
        f.close()

def write_txt(fileName,lists,model = 'normal'):

    """
        按行写入
    """

    if model == 'normal':
        f = open(fileName,'w', encoding='utf8')
    else:    
        f = open(fileName,'a', encoding='utf8')
    for i in tqdm(lists):
        f.write(str(i))
        f.write('\n')
    f.close()

def write_npy(fileName,lists):

    """
        按行写入
    """

    np.save(fileName, lists)


from sklearn.model_selection import train_test_split
from collections import Counter

def random_split_data(all_data,label_name,test_size = 0.20,seed = 0):

    labels = []
    for line in all_data:
        labels.append(int(line[label_name]))
    train_idx, test_idx, _, _ = train_test_split(range(len(labels)), labels, stratify=labels,
                                                    shuffle=True, test_size=test_size, random_state=seed)
    
    train_data,test_data = [],[]

    for i in train_idx:
        train_data.append(all_data[i])

    for i in test_idx:
        test_data.append(all_data[i])

    return train_data,test_data    

def count_label(labels):

    result = Counter(labels)
    return(result)